@@ -15,6 +15,7 @@ class RestAPIVariables:
     def json_vars(self):
         self.COTSERVICE = 'CoTService'
         self.DATAPACKAGESERVICE = 'TCPDataPackageService'
+        self.SSLCOTSERVICE = 'SSLCoTService'
         self.IP = 'IP'
         self.PORT = 'PORT'
         self.STATUS = 'STATUS'
@@ -33,16 +34,22 @@ class RestAPIVariables:
         self.defaultDataPackageIP = '0.0.0.0'
         self.defaultDataPackagePort = 8080
         self.defaultDataPackageStatus = 'start'
+        self.defaultSSLCoTIP = '0.0.0.0'
+        self.defaultSSLCoTPort = 15778
+        self.defaultSSLCoTStatus = 'start'
 
     def json_content(self):
         self.JsonStatusStartAll = {"CoTService":
                                    {"IP": self.getdefaultCoTIP(), "PORT": self.getdefaultCoTPort(), "STATUS": self.getdefaultCoTStatus()},
                                "TCPDataPackageService":
-                                   {"IP": self.getdefaultDataPackageIP(), "PORT": self.getdefaultDataPackagePort(), "STATUS": self.getdefaultDataPackageStatus()}}
-
+                                   {"IP": self.getdefaultDataPackageIP(), "PORT": self.getdefaultDataPackagePort(), "STATUS": self.getdefaultDataPackageStatus()},
+                                   "SSLCoTService":
+                                       {"IP":self.getdefaultSSLCoTIP(), "PORT": self.getdefaultSSLCoTPort(), "STATUS": self.getdefaultSSLCoTStatus()}}
         self.JsonStatusStopAll = {"CoTService":
                                       {"STATUS": "stop"},
                                   "TCPDataPackageService":
+                                      {"STATUS": "stop"},
+                                  "SSLCoTService":
                                       {"STATUS": "stop"}}
         self.JsonStatusStartCoTService = {}
 
@@ -71,6 +78,24 @@ class RestAPIVariables:
     def getdefaultCoTStatus(self):
         return self.defaultCoTStatus
 
+    def setdefaultSSLCoTPort(self, defaultSSLCoTPort):
+        self.defaultSSLCoTPort = defaultSSLCoTPort
+
+    def getdefaultSSLCoTPort(self):
+        return self.defaultSSLCoTPort
+
+    def setdefaultSSLCoTIP(self, defaultSSLCoTIP):
+        self.defaultSSLCoTIP = defaultSSLCoTIP
+
+    def getdefaultSSLCoTIP(self):
+        return self.defaultSSLCoTIP
+
+    def setdefaultSSLCoTStatus(self, defaultSSLCoTStatus):
+        self.defaultSSLCoTStatus = defaultSSLCoTStatus
+
+    def getdefaultSSLCoTStatus(self):
+        return self.defaultSSLCoTStatus
+
     def setdefaultDataPackageIP(self, defaultDataPackageIP):
         self.defaultDataPackageIP = defaultDataPackageIP
 
@@ -87,4 +112,4 @@ class RestAPIVariables:
         self.defaultDataPackageStatus = defaultDataPackageStatus
 
     def getdefaultDataPackageStatus(self):
-        return self.defaultDataPackageStatus
\ No newline at end of file
+        return self.defaultDataPackageStatus
