@@ -3,6 +3,7 @@ import threading
 import argparse
 from FreeTAKServer.controllers.CreateStartupFilesController import CreateStartupFilesController
 from FreeTAKServer.controllers.services.TCPDataPackageService import TCPDataPackageService as TCPFlaskFunctions
+from FreeTAKServer.controllers.services.SSLDataPackageService import SSLDataPackageService as SSLFlaskFunctions
 from FreeTAKServer.controllers.configuration.OrchestratorConstants import OrchestratorConstants
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
@@ -12,6 +13,7 @@ from FreeTAKServer.model.SimpleClient import SimpleClient
 import time
 from FreeTAKServer.controllers.AddDataToCoTList import AddDataToCoTList
 from FreeTAKServer.model.FilterGroup import FilterGroup
+from FreeTAKServer.controllers.services.SSLCoTServiceController import SSLCoTServiceController
 from FreeTAKServer.controllers.services.TCPCoTServiceController import TCPCoTServiceController
 from FreeTAKServer.controllers.DatabaseControllers.DatabaseController import DatabaseController
 
@@ -29,6 +31,7 @@ class FTS:
         self.ReceiveConnectionsReset = None
         self.CoTPoisonPill = None
         self.ClientDataPipe = None
+        self.SSLClientDataPipe = None
         self.clientArray = []
         self.socketCount = 0
         self.pipeList = {}
@@ -104,11 +107,14 @@ class FTS:
 
     def start_tcp_data_package_service(self, FTSServiceStartupConfigObject):
         try:
+            tcp_data_package_service_pipe, self.tcp_data_package_service_pipe = multiprocessing.Pipe(duplex=True)
             print('start 213')
             self.TCPDataPackageService = multiprocessing.Process(target=TCPFlaskFunctions().startup,
-                                                                 args=(FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServiceIP, FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServicePort))
+                                                                 args=(FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServiceIP, FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServicePort, tcp_data_package_service_pipe))
             print('starting now')
             self.TCPDataPackageService.start()
+            self.pipeList['tcp_data_package_service_pipe'] = self.tcp_data_package_service_pipe
+            self.FilterGroup.sources.append(self.tcp_data_package_service_pipe)
             time.sleep(2)
             return 1
         except Exception as e:
@@ -128,6 +134,73 @@ class FTS:
             return -1
         return 1
 
+    def start_ssl_data_package_service(self, FTSServiceStartupConfigObject):
+        try:
+            print('start 213')
+            ssl_data_package_service, self.ssl_data_package_service = multiprocessing.Pipe(duplex=True)
+            self.SSLDataPackageService = multiprocessing.Process(target=SSLFlaskFunctions().startup,
+                                                              args=(FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceIP, FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServicePort, ssl_data_package_service))
+            print('starting SSL now')
+            self.SSLDataPackageService.start()
+            self.pipeList['ssl_data_package_service'] = self.ssl_data_package_service
+            self.FilterGroup.sources.append(self.ssl_data_package_service)
+            time.sleep(2)
+            return 1
+        except Exception as e:
+            logger.error('there has been an exception in the individual starting of the Data Packages Service ' + str(e))
+            return -1
+
+    def stop_ssl_data_package_service(self):
+        try:
+            self.SSLDataPackageService.terminate()
+        except Exception as e:
+            logger.error("there's been an exception in the termination of DataPackage Service " + str(e))
+            return -1
+        try:
+            self.SSLDataPackageService.join()
+        except Exception as e:
+            logger.error("there's been an exception in the joining of DataPackage Service " + str(e))
+            return -1
+        return 1
+
+    def start_SSL_CoT_service(self, FTSServiceStartupConfigObject):
+        try:
+            self.SSLClientDataPipe, SSLClientDataPipeParentChild = multiprocessing.Pipe()
+            self.SSLCoTServicePipe, self.SSLCoTServiceFTSPipe = multiprocessing.Pipe()
+            self.SSLCoTPoisonPill = multiprocessing.Event()
+            self.SSLCoTPoisonPill.set()
+            self.ReceiveConnectionsReset = multiprocessing.Event()
+            self.SSLCoTService = multiprocessing.Process(target=SSLCoTServiceController().start, args=(FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceIP, FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServicePort, self.SSLCoTPoisonPill, SSLClientDataPipeParentChild, self.ReceiveConnectionsReset, self.SSLCoTServicePipe))
+            self.SSLCoTService.start()
+            self.pipeList['SSLCoTServiceFTSPipe'] = self.SSLCoTServiceFTSPipe
+            self.FilterGroup.sources.append(self.SSLCoTServiceFTSPipe)
+            self.FilterGroup.receivers.append(self.SSLCoTServiceFTSPipe)
+            print('SSL CoTService started')
+            return 1
+        except Exception as e:
+            logger.error('an exception has been thrown in SSL CoT service startup ' + str(e))
+            return -1
+
+    def stop_SSL_CoT_service(self):
+        try:
+            self.SSLClientDataPipe.close()
+            self.SSLCoTPoisonPill.clear()
+
+            time.sleep(0.1)
+            if self.CoTService.is_alive():
+                self.CoTService.terminate()
+                self.CoTService.join()
+            else:
+                self.CoTService.join()
+
+            self.FilterGroup.sources.remove(self.TCPCoTServiceFTSPipe)
+            self.FilterGroup.receivers.remove(self.TCPCoTServiceFTSPipe)
+
+        except Exception as e:
+            logger.error("there's been an exception in the stopping of CoT Service " + str(e))
+            return -1
+        return 1
+
     #change object name to FTSServiceStartupConfigObject
     def start_all(self, FTSServiceStartupConfigObject):
         try:
@@ -140,6 +213,14 @@ class FTS:
             else:
                 pass
 
+            if FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceStatus == 'start':
+                self.start_ssl_data_package_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceStatus == 'stop':
+                self.stop_ssl_data_package_service()
+            else:
+                pass
+
             if FTSServiceStartupConfigObject.CoTService.CoTServiceStatus == 'start':
                 self.start_CoT_service(FTSServiceStartupConfigObject)
 
@@ -148,6 +229,15 @@ class FTS:
             else:
                 pass
 
+            if FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceStatus == 'start':
+                self.start_SSL_CoT_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceStatus == 'stop':
+                self.stop_SSL_CoT_service()
+
+            else:
+                pass
+
             return 1
         except Exception as e:
             logger.error('there has been an exception in FTS start_all ' + str(e))
@@ -211,6 +301,17 @@ class FTS:
     def check_server_status(self):
         return self.FTSServiceStartupConfigObject
 
+    def help(self):
+        print('start_all: to begin all services type')
+        print('start_CoT_service: to begin CoT service type')
+        print('start_data_package_service: to begin data package service  type')
+        print('stop_all: to terminate all services type')
+        print('stop_CoT_service: to terminate CoT service type')
+        print('stop_data_package_service: to begin data package service type')
+        print('check_service_status: to check the status of the services type')
+        print('show_users: to show connected user information type')
+        print('kill: to kill the full server type')
+
     def show_users(self):
         '''
         this method is used only by commands submitted over the rest interface
@@ -294,8 +395,8 @@ class FTS:
                     pass
         except Exception as e:
             pass
-    
-    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, RestAPIPort, RestAPIIP, AutoStart):
+
+    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart):
         try:
             if AutoStart == 'False':
                 StartupObject = FTSObj()
@@ -317,6 +418,9 @@ class FTS:
                 StartupObject.RestAPIService.RestAPIServiceIP = RestAPIIP
                 StartupObject.RestAPIService.RestAPIServiceStatus = 'start'
 
+                StartupObject.SSLCoTService.SSLCoTServiceStatus = 'start'
+                StartupObject.SSLCoTService.SSLCoTServiceIP = SSLCoTIP
+                StartupObject.SSLCoTService.SSLCoTServicePort = SSLCoTPort
                 self.start_restAPI_service(StartupObject)
 
                 self.start_all(StartupObject)
@@ -325,6 +429,7 @@ class FTS:
             while True:
                 self.checkPipes()
                 self.clientArray = self.receive_data_froCoT_service_thread(self.ClientDataPipe, self.clientArray)
+                self.clientArray = self.receive_data_froCoT_service_thread(self.SSLClientDataPipe, self.clientArray)
 
         except Exception as e:
             logger.error('exception in the startup of FTS ' + str(e))
@@ -336,6 +441,10 @@ if __name__ == "__main__":
                             default=FTSObj().CoTService.CoTServicePort)
         parser.add_argument('-CoTIP', type=str, help=OrchestratorConstants().COTIPDESC,
                             default=FTSObj().CoTService.CoTServiceIP)
+        parser.add_argument('-SSLCoTPort', type=int, help=OrchestratorConstants().SSLCOTPORTDESC,
+                            default=FTSObj().SSLCoTService.SSLCoTServicePort)
+        parser.add_argument('-SSLCoTIP', type=str, help=OrchestratorConstants().SSLCOTIPDESC,
+                            default=FTSObj().SSLCoTService.SSLCoTServiceIP)
         parser.add_argument('-DataPackagePort', type=int, help=OrchestratorConstants().APIPORTDESC,
                             default=FTSObj().TCPDataPackageService.TCPDataPackageServicePort)
         parser.add_argument('-DataPackageIP', type=str, help=OrchestratorConstants().APIPORTDESC,
@@ -347,6 +456,6 @@ if __name__ == "__main__":
         parser.add_argument('-AutoStart', type=str, help='wether or not you want all services to start or only the root service and the RestAPI service', default='True')
         args = parser.parse_args()
         CreateStartupFilesController()
-        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.RestAPIPort, args.RestAPIIP, args.AutoStart)
+        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart)
     except Exception as e:
         print(e)
\ No newline at end of file
