@@ -72,12 +72,90 @@ def sessions():
 def handle_message():
     emit('data', json.dumps({'abc234': 'test123'}))
 
-@socketio.on('Update')
-def handel_updates(msg):
-    print(msg)
-    emitUpdatesThread = threading.Thread(target=emitUpdates, args=(APIPipe,), daemon=True)
-    emitUpdatesThread.start()
-    emitUpdatesThread.join()
+@socketio.on('users')
+def show_users():
+    '''import random
+    jsondata = {"Users":
+                []}
+    for user in range(random.randint(1, 100)):
+        user = {"ip": f"{random.randint(1, 255)}.{random.randint(1, 255)}.{random.randint(1, 255)}.{random.randint(1, 255)}",
+                "callsign": f"{}"}
+        jsondata["Users"].append(user)'''
+
+@socketio.on('logs')
+
+@socketio.on('serviceInfo')
+def show_service_info():
+    import random
+    import datetime as dt
+    DATETIME_FMT = "%Y-%m-%dT%H:%M:%S.%fZ"
+    timer = dt.datetime
+    now = timer.utcnow()
+    zulu = now.strftime(DATETIME_FMT)
+    add = dt.timedelta(seconds=random.randint(60, 10000))
+    stale_part = dt.datetime.strptime(zulu, DATETIME_FMT) - add
+    starttime = stale_part.strftime(DATETIME_FMT)
+    jsonObject = {
+        "services": {
+            "SSL_CoT_service": {
+                          "status": random.choice(['on', 'off']),
+                          "port": random.randint(1, 65535)
+                      },
+            "TCP_CoT_service": {
+                          "status": random.choice(['on', 'off']),
+                          "port": random.randint(1, 65535)
+                      },
+            "SSL_DataPackage_service": {
+                          "status": random.choice(['on', 'off']),
+                          "port": random.randint(1, 65535)
+                      },
+            "TCP_DataPackage_service": {
+                          "status": random.choice(['on', 'off']),
+                          "port": random.randint(1, 65535)
+                      }
+        },
+        "starttime": str(starttime)
+    }
+
+    emit('serviceInfo', json.dumps(jsonObject))
+
+@socketio.on("serverHealth")
+def serverHealth():
+    import random
+    jsondata = {
+                "CPU": random.randint(1, 100),
+                "memory": random.randint(1, 100),
+                "disk": random.randint(1, 100)
+                }
+    emit('serviceInfo', json.dumps(jsondata))
+
+@app.route("/systemStatus", methods=["GET"])
+def systemStatus():
+    import random
+    jsondata = {
+        "services": {
+            "SSL_CoT_service": {
+                "status_expected": random.choice(['on', 'off']),
+                "status_actual": random.choice(['on', 'off'])
+            },
+            "TCP_CoT_service": {
+                "status_expected": random.choice(['on', 'off']),
+                "satus_actual": random.choice(['on', 'off'])
+            },
+            "SSL_DataPackage_service": {
+                "status_expected": random.choice(['on', 'off']),
+                "status_actual": random.choice(['on', 'off'])
+            },
+            "TCP_DataPackage_service": {
+                "status_expected": random.choice(['on', 'off']),
+                "status_actual": random.choice(['on', 'off'])
+            },
+            "TCP_API_service": {
+                "status_expected": random.choice(['on', 'off']),
+                "status_actual": random.choice(['on', 'off'])
+            }
+        }
+    }
 
 @app.route("/SendGeoChat", methods=[restMethods.POST])
 def SendGeoChat():
@@ -300,6 +378,73 @@ def DataPackageTable():
     else:
         return 'endpoint can only be accessed by approved IPs', 401
 
+def getMission():
+    import uuid
+    import random_word
+    import random
+    maincontent = {
+        "name": str(random_word.RandomWords().get_random_word()),
+        "description": str(' '.join(random_word.RandomWords().get_random_words(limit=4))),
+        "chatRoom": "",
+        "tool": "public",
+        "keywords": random_word.RandomWords().get_random_words(limit=random.randint(1, 3)),
+        "creatorUid": str(random_word.RandomWords().get_random_word()),
+        "createTime": "2020-12-09T15:53:42.873Z",
+        "groups": random_word.RandomWords().get_random_words(limit=random.randint(1, 3)),
+        "externalData": [],
+        "uids": [{
+            "data": str(uuid.uuid4()),
+            "timestamp": "2020-12-09T15:58:10.635Z",
+            "creatorUid": str(uuid.uuid4()),
+            "details": {
+                "type": "a-h-G",
+                "callsign": "R.9.155734",
+                "iconsetPath": "COT_MAPPING_2525B/a-h/a-h-G"
+            }
+        }
+        ],
+        "contents": [{
+            "data": {
+                "filename": str(random_word.RandomWords().get_random_word()),
+                "keywords": [],
+                "mimeType": "application/octet-stream",
+                "name": str(' '.join(random_word.RandomWords().get_random_words(limit=random.randint(1, 2)))),
+                "submissionTime": "2020-12-09T15:55:21.468Z",
+                "submitter": str(random_word.RandomWords().get_random_word()),
+                "uid": str(uuid.uuid4()),
+                "hash": str(random.getrandbits(128)),
+                "size": random.randint(1000, 100000)
+            },
+            "timestamp": "2020-12-09T15:55:21.559Z",
+            "creatorUid": str(random_word.RandomWords().get_random_word())
+        }
+        ],
+        "passwordProtected": random.choice(['true', 'false'])
+    }
+    return maincontent
+@app.route("/missionTable", methods=['GET'])
+def mission_table():
+    try:
+        import random
+
+        jsondata = {
+            "version": "3",
+            "type": "Mission",
+            "data": [getMission() for x in range(random.randint(1, 5))],
+            "nodeId": "6ff99444fa124679a3943ee90308a44c9d794c02-e5a5-42b5-b4c8-625203ea1287"
+        }
+        return json.dumps(jsondata)
+    except Exception as e:
+        return e, 500
+
+@app.route("/excheckTable", methods=["GET"])
+def excheck_table():
+    try:
+        from FreeTAKServer.controllers.ExCheckControllers.templateToJsonSerializer import templateSerializer
+        jsondata = templateSerializer().convert_object_to_json(DatabaseController().query_ExCheck())
+        1 == 1
+    except Exception as e:
+        return str(e), 500
 @app.route('/checkStatus', methods=[restMethods.GET])
 def check_status():
     try:
@@ -343,6 +488,19 @@ def All():
                 else:
                     pass
 
+                if jsonVars.SSLCOTSERVICE in json:
+
+                    SSLCoTservice = json[jsonVars.SSLCOTSERVICE]
+                    FTSObject.SSLCoTService.SSLCoTServiceIP = SSLCoTservice.get(jsonVars.IP)
+                    try:
+                        FTSObject.SSLCoTService.SSLCoTServicePort = int(SSLCoTservice.get(jsonVars.PORT))
+                    except:
+                        FTSObject.SSLCoTService.SSLCoTServicePort = ''
+                    FTSObject.SSLCoTService.SSLCoTServiceStatus = SSLCoTservice.get(jsonVars.STATUS)
+
+                else:
+                    pass
+
                 CommandPipe.send([functionNames.Status, FTSObject])
                 out = CommandPipe.recv()
                 return '200', 200
@@ -356,8 +514,7 @@ def receiveUpdates():
         try:
             update = APIPipe.recv()
             global UpdateArray
-            UpdateArray.append(update)
-            print(UpdateArray)
+            emitUpdates(update)
         except Exception as e:
             print(e)
 
@@ -377,20 +534,12 @@ def emitUpdates(Updates):
     returnValue = []
     for client in data:
         returnValue.append(ApplyFullJsonController().serialize_model_to_json(client))
-    socketio.emit('up', json.dumps(returnValue))
-    while True:
-        try:
-            for _ in UpdateArray:
-                returnValue = []
-                print(UpdateArray)
-                data = UpdateArray.pop(0)
-                for client in data:
-                    returnValue.append(ApplyFullJsonController().serialize_model_to_json(client))
-                socketio.emit('up', json.dumps(returnValue))
-            socketio.sleep(0.1)
-        except Exception as e:
-            print(e)
-            pass
+    socketio.emit('up', json.dumps(returnValue), broadcast = True)
+    data = Updates
+    for client in data:
+        returnValue.append(ApplyFullJsonController().serialize_model_to_json(client))
+    socketio.emit('up', json.dumps(returnValue), broadcast = True)
+    return 1
 
 def test(json):
     modelObject = Event.dropPoint()
@@ -419,7 +568,6 @@ class RestAPI:
         APIPipe = APIPipea
         CommandPipe = CommandPipea
         threading.Thread(target=receiveUpdates, daemon=True, args=()).start()
-        print('rest api starting')
         socketio.run(app, host=IP, port=Port)
         # try below if something breaks
         # socketio.run(app, host='0.0.0.0', port=10984, debug=True, use_reloader=False)
@@ -436,6 +584,6 @@ class RestAPI:
         return model
 
 if __name__ == '__main__':
-    RestAPI().startup()
+    excheck_table()
     #    app.run(host="127.0.0.1", port=80)
 
