@@ -1,9 +1,8 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModel.ChecklistColumns import ChecklistColumns
 from FreeTAKServer.model.FTSModel.ChecklistDetails import ChecklistDetails
 from FreeTAKServer.model.FTSModel.ChecklistTasks import ChecklistTasks
 
-class Checklist(FTSProtocolObject):
+class Checklist:
     @staticmethod
     def Checklist():
         checklist = Checklist()
