@@ -1,7 +1,6 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.CreatorCallsignVariables import CreatorCallsignVariables as vars
 
-class CreatorCallsign(FTSProtocolObject):
+class CreatorCallsign:
     @staticmethod
     def Checklist(INTAG = vars.Checklist().INTAG):
         creatorCallsign = CreatorCallsign()
