@@ -5,7 +5,7 @@ class Hash:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         hash = Hash()
 
         hash.setINTAG(INTAG)
