@@ -5,7 +5,7 @@ class Keywords:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         keywords = Keywords()
 
         keywords.setINTAG(INTAG)
