@@ -1,7 +1,13 @@
 from FreeTAKServer.model.FTSModelVariables.NameVariables import NameVariables as vars
 class Name:
     @staticmethod
-    def CreateExCheckTemplate(INTAG = vars.CreateExCheckTemplate().INTAG):
+    def ExcheckUpdate(INTAG = vars.ExcheckUpdate().INTAG):
+        name = Name()
+        name.setINTAG(INTAG)
+        return name
+
+    @staticmethod
+    def Checklist(INTAG = vars.Checklist().INTAG):
         name = Name()
         name.setINTAG(INTAG)
         return name
