@@ -17,7 +17,13 @@ class Uid:
         return uid
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG = vars.CreateExCheckTemplate().INTAG):
+    def ExcheckUpdate(INTAG = vars.ExcheckUpdate().INTAG):
+        uid = Uid()
+        uid.setINTAG(INTAG)
+        return uid
+
+    @staticmethod
+    def Checklist(INTAG = vars.Checklist().INTAG):
         uid = Uid()
         uid.setINTAG(INTAG)
         return uid
@@ -34,3 +40,5 @@ class Uid:
     def setINTAG(self, INTAG = None):
         self.INTAG = INTAG
 
+
+
