@@ -8,13 +8,13 @@ from sqlalchemy.orm import relationship
 class ExCheckData(Base):
     __tablename__ = 'ExCheckData'
     PrimaryKey = Column(ForeignKey("ExCheck.PrimaryKey"), primary_key = True, autoincrement=True)
-    filename = Column(String(100))
-    mimeType = Column(String(100))
-    name = Column(String(100))
-    submissionTime = Column(String(100))
-    submitter = Column(String(100))
-    uid = Column(String(100))
-    hash = Column(String(100), unique=True)
+    filename = Column(String)
+    mimeType = Column(String)
+    name = Column(String)
+    submissionTime = Column(String)
+    submitter = Column(String)
+    uid = Column(String)
+    hash = Column(String)
     size = Column(Integer)
-    tool = Column(String(100))
-    keywords = relationship("ExCheckKeywords", uselist=False, backref="ExCheckData", cascade="all, delete")
\ No newline at end of file
+    tool = Column(String)
+    keywords = relationship("ExCheckKeywords", uselist=False)
\ No newline at end of file
