@@ -6,6 +6,6 @@ from sqlalchemy import Integer
 class ExCheckKeywords(Base):
     __tablename__ = 'ExCheckKeywords'
     PrimaryKey = Column(ForeignKey("ExCheckData.PrimaryKey"), primary_key = True, autoincrement=True)
-    name = Column(String(100))
-    description = Column(String(100))
-    callsign = Column(String(100))
\ No newline at end of file
+    name = Column(String)
+    description = Column(String)
+    callsign = Column(String)
\ No newline at end of file
