@@ -1,10 +1,14 @@
 from .FTSVariables import FTSVariables as vars
 from .CoTService import CoTService
 from .TCPDataPackageService import TCPDataPackageService
+from .SSLDataPackageService import SSLDataPackageService
 from .RestAPIService import RestAPIService
+from .SSLCoTService import SSLCoTService
 
 class FTS:
     def __init__(self):
         self.CoTService = CoTService()
         self.TCPDataPackageService = TCPDataPackageService()
-        self.RestAPIService = RestAPIService()
\ No newline at end of file
+        self.SSLDataPackageService = SSLDataPackageService()
+        self.RestAPIService = RestAPIService()
+        self.SSLCoTService = SSLCoTService()
\ No newline at end of file
